@@ -2,7 +2,7 @@ package Web::Hippie;
 
 use strict;
 use 5.008_001;
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 use parent 'Plack::Middleware';
 
 use Plack::Util::Accessor qw( root init on_error on_message trusted_origin );
@@ -126,9 +126,9 @@ sub handler_mxhr {
              ]]);
         $writer->write("--" . $boundary. "\n");
         $env->{'hippie.handle'} = Web::Hippie::Handle::MXHR->new
-            ( id       => $client_id,
-              boundary => $boundary,
-              writer   => $writer );
+            ({ id       => $client_id,
+               boundary => $boundary,
+               writer   => $writer });
         $env->{'PATH_INFO'} = '/init';
 
         $handler->($env);
@@ -247,8 +247,8 @@ sub handler_ws {
 
         use Web::Hippie::Handle::WebSocket;
         $env->{'hippie.handle'} = Web::Hippie::Handle::WebSocket->new
-            ( id => $client_id,
-              h  => $h );
+            ({ id => $client_id,
+               h  => $h });
         $h->on_error( $self->connection_cleanup($env, $handler, $h) );
 
         $h->push_write($hs);
